@@ -16,6 +16,12 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include <glib/gi18n-lib.h>
+
 #include "e-source-mapi-folder.h"
 
 #include "e-mapi-backend.h"
@@ -28,10 +34,13 @@ void e_module_unload (GTypeModule *type_module);
 G_MODULE_EXPORT void
 e_module_load (GTypeModule *type_module)
 {
-	e_mapi_backend_type_register (type_module);
-	e_mapi_backend_factory_type_register (type_module);
+	bindtextdomain (GETTEXT_PACKAGE, EXCHANGE_MAPI_LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
 	e_source_mapi_folder_type_register (type_module);
+
+	e_mapi_backend_type_register (type_module);
+	e_mapi_backend_factory_type_register (type_module);
 }
 
 G_MODULE_EXPORT void
