@@ -181,7 +181,7 @@ rp_to_gba(const struct ema_RecurrencePattern *rp, GByteArray *gba)
 		            sizeof (guint32) * rp->DeletedInstanceCount);
 	}
 	GBA_APPEND_LVAL(gba, rp->ModifiedInstanceCount);
-	if ( rp->DeletedInstanceCount ) {
+	if ( rp->ModifiedInstanceCount ) {
 		GBA_APPEND (gba, rp->ModifiedInstanceDates,
 		            sizeof (guint32) * rp->ModifiedInstanceCount);
 	}
@@ -296,6 +296,10 @@ arp_to_gba(const struct ema_AppointmentRecurrencePattern *arp, GByteArray *gba)
 	for (i = 0; i < arp->ExceptionCount; ++i) {
 		ee_to_gba (&arp->ExtendedException[i], arp, i, gba);
 	}
+	GBA_APPEND_LVAL (gba, arp->ReservedBlock2Size);
+	if (arp->ReservedBlock2Size) {
+		GBA_APPEND (gba, arp->ReservedBlock2, arp->ReservedBlock2Size);
+	}
 }
 
 static gboolean
@@ -501,6 +505,13 @@ gba_to_arp(const GByteArray *gba, ptrdiff_t *off,
 		}
 	}
 
+	GBA_DEREF_OFFSET (gba, *off, arp->ReservedBlock2Size, guint32);
+	if (arp->ReservedBlock2Size) {
+		arp->ReservedBlock2 = g_new (gchar, arp->ReservedBlock2Size);
+		GBA_MEMCPY_OFFSET (gba, *off, arp->ReservedBlock2,
+		                   arp->ReservedBlock2Size);
+	}
+
 	return TRUE;
 }
 
