@@ -30,6 +30,36 @@
 #include "e-mapi-debug.h"
 #include "e-mapi-connection.h"
 
+#define e_mapi_return_data_cal_error_if_fail(expr, _code)			\
+	G_STMT_START {								\
+		if (G_LIKELY (expr)) {						\
+		} else {							\
+			g_log (G_LOG_DOMAIN,					\
+				G_LOG_LEVEL_CRITICAL,				\
+				"file %s: line %d (%s): assertion `%s' failed",	\
+				__FILE__, __LINE__, G_STRFUNC, #expr);		\
+			g_set_error (error, E_DATA_CAL_ERROR, (_code),		\
+				"file %s: line %d (%s): assertion `%s' failed",	\
+				__FILE__, __LINE__, G_STRFUNC, #expr);		\
+			return;							\
+		}								\
+	} G_STMT_END
+
+#define e_mapi_return_data_book_error_if_fail(expr, _code)			\
+	G_STMT_START {								\
+		if (G_LIKELY (expr)) {						\
+		} else {							\
+			g_log (G_LOG_DOMAIN,					\
+				G_LOG_LEVEL_CRITICAL,				\
+				"file %s: line %d (%s): assertion `%s' failed",	\
+				__FILE__, __LINE__, G_STRFUNC, #expr);		\
+			g_set_error (error, E_DATA_BOOK_ERROR, (_code),		\
+				"file %s: line %d (%s): assertion `%s' failed",	\
+				__FILE__, __LINE__, G_STRFUNC, #expr);		\
+			return;							\
+		}								\
+	} G_STMT_END
+
 typedef struct _EMapiCancellableRecMutex {
 	GRecMutex rec_mutex;
 	GMutex cond_mutex;
